v2.0.0
======

Features
--------

- Implement subrepos for Git repos.


Deprecations and Removals
-------------------------

- Removed legacy names.


v1.3.0
======

Features
--------

- Remove mask for environment when invoking hg as the underlying issue has been corrected. (#7)


v1.2.0
======

Features
--------

- Require Python 3.8 or later.


v1.1.0
======

Added ``repo()`` function.

Implemented ``Git.get_ancestral_tags()``.

v1.0.0
======

Initial release, based on ``hgtools`` 10.
